OC.L10N.register(
    "core",
    {
    "Please select a file." : "Выберите файл.",
    "File is too big" : "Файл слишком велик",
    "The selected file is not an image." : "Выбранный файл не является изображением.",
    "The selected file cannot be read." : "Выбранный файл не может быть прочитан.",
    "The file was uploaded" : "Файл загружен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Загруженный файл превышает директиву upload_max_filesize в php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Загруженный файл превышает директиву MAX_FILE_SIZE, указанную в HTML-форме.",
    "The file was only partially uploaded" : "Файл получен частично",
    "No file was uploaded" : "Файл не получен",
    "Missing a temporary folder" : "Отсутствует временный каталог",
    "Could not write file to disk" : "Невозможно записать файл на диск",
    "A PHP extension stopped the file upload" : "Загрузка файла была прервана модулем расширений PHP",
    "Invalid file provided" : "Указан недопустимый файл",
    "No image or file provided" : "Не указано изображение или файл",
    "Unknown filetype" : "Неизвестный тип файла",
    "An error occurred. Please contact your admin." : "Произошла ошибка. Свяжитесь со своим администратором.",
    "Invalid image" : "Недопустимое изображение",
    "No temporary profile picture available, try again" : "Временная картинка профиля недоступна, повторите попытку",
    "No crop data provided" : "Не указана информация о кадрировании",
    "No valid crop data provided" : "Не указаны корректные данные о кадрировании",
    "Crop is not square" : "Кадр не является квадратом",
    "State token does not match" : "Токен состояния не совпадает",
    "Invalid app password" : "Неверный пароль приложения",
    "Could not complete login" : "Не удалось завершить вход в систему",
    "Your login token is invalid or has expired" : "Ваш токен неверен или истёк",
    "Login" : "Войти",
    "Password reset is disabled" : "Сброс пароля отключён",
    "Could not reset password because the token is expired" : "Не было возможности сбросить пароль в связи с просроченным токеном",
    "Could not reset password because the token is invalid" : "Не было возможности сбросить пароль в связи с неверным токеном",
    "%s password reset" : "Сброс пароля %s",
    "Password reset" : "Сброс пароля",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на кнопку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Для сброса пароля нажмите на ссылку. Если вы не запрашивали сброс пароля, просто проигнорируйте это письмо.",
    "Reset your password" : "Сбросить пароль",
    "Nextcloud Server" : "Сервер Nextcloud",
    "Some of your link shares have been removed" : "Некоторые из ваших ссылок на общие ресурсы были удалены",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Из-за ошибки в безопасности нам пришлось удалить некоторые из ваших ссылок на опубликованные файлы или папки. Перейдите по ссылке для получения дополнительной информации.",
    "The user limit of this instance is reached." : "Достигнут лимит пользователей этого экземпляра",
    "Enter your subscription key to increase the user limit. For more information about Nextcloud Enterprise see our website." : "Введите ключ подписки, чтобы увеличить лимит пользователей. Для получения дополнительной информации о Nextcloud Enterprise посетите наш веб-сайт.",
    "Preparing update" : "Подготовка к обновлению",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Шаг восстановления:",
    "Repair info:" : "Информация восстановления:",
    "Repair warning:" : "Предупреждение восстановления:",
    "Repair error:" : "Ошибка восстановления:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Автоматические обновления отключены в файле конфигурации  «config.php». Выполните обновление из командной строки.",
    "Turned on maintenance mode" : "Включён режим обслуживания ",
    "Turned off maintenance mode" : "Отключён режим обслуживания",
    "Maintenance mode is kept active" : "Режим обслуживания оставлен включенным",
    "Updating database schema" : "Выполняется обновление схемы базы данных",
    "Updated database" : "База данных обновлена",
    "Update app \"%s\" from App Store" : "Выполняется обновление приложения «%s»",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Проверка возможности обновления схемы базы данных %s (может занять длительное время, зависящее от размера базы данных)",
    "Updated \"%1$s\" to %2$s" : "Приложение «%1$s» обновлено до версии %2$s",
    "Set log level to debug" : "Установлен отладочный уровень протоколирования",
    "Reset log level" : "Сброс уровня протоколирования",
    "Starting code integrity check" : "Начат процесс проверки целостности кода",
    "Finished code integrity check" : "Проверка целостности кода завершена",
    "%s (incompatible)" : "%s (несовместимое)",
    "The following apps have been disabled: %s" : "Были отключены следующие приложения: %s",
    "Already up to date" : "Не нуждается в обновлении",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Веб-сервер ещё не настроен должным образом для синхронизации файлов: похоже, что не работоспособен интерфейс WebDAV.",
    "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Веб-сервер не настроен должным образом для разрешения «{url}». Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Веб-сервер не настроен должным образом для разрешения пути «{url}». Скорее всего, это связано с конфигурацией веб-сервера, которая не была обновлена для непосредственного доступа к этой папке. Сравните свою конфигурацию с поставляемыми правилами перезаписи в файле «.htaccess» для Apache или предоставленными в документации для Nginx на {linkstart}странице документации ↗{linkend}. Для Nginx, как правило, требуется обновить строки, начинающиеся с «location ~».",
    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Веб-сервер не настроен должным образом для передачи файлов шрифтов в формате .woff2, что необходимо для правильной работы Nextcloud версии 15. Как правило, это  связано с конфигурацией веб-сервера Nginx. Сравните используемую конфигурацию с рекомендуемой конфигурацией из {linkstart}документации ↗{linkend}.",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP не настроен правильно для получения переменных системного окружения. Запрос getenv(\"PATH\") возвращает пустые результаты.",
    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Обратитесь к {linkstart}документации по установке ↗{linkend} для получения информации по правильной настройке PHP, что особенно важно в случае использования php-fpm.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Файл конфигурации доступен только для чтения, что не позволяет изменять некоторые настройки из веб-интерфейса. Обратите внимание, что для установки обновлений потребуется разрешить запись в файл конфигурации.",
    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Параметры сервера электронной почты ещё не заданы или не проверены. Чтобы произвести настройку, перейдите в раздел {mailSettingsStart}основных параметров{mailSettingsEnd}, после чего нажмите кнопку «Отправить сообщение» для проверки.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "База данных не использует режиме изоляции транзакций «READ COMMITED». Такое поведение может вызвать проблемы при одновременном выполнении нескольких операций.",
    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Отсутствует модуль PHP «fileinfo». Настоятельно рекомендуется включить этот модуль для улучшения определения MIME-типов файлов.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Отключена блокировка передаваемых файлов, что может привести к состоянию гонки. Для предупреждения возможных проблем включите параметр «filelocking.enabled» в файле «config.php». Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Пожалуйста, не забудьте установить опцию \"overwrite.cli.url\" в вашем config.php с указанием URL-адреса, который ваши пользователи в основном используют для доступа к этому Nextcloud. Предложение: \"{suggestedOverwriteCliURL}\". В противном случае могут возникнуть проблемы с генерацией URL-адреса через cron. (Однако возможно, что предлагаемый URL-адрес не является тем URL-адресом, который ваши пользователи в основном используют для доступа к этому Nextcloud. В любом случае лучше всего перепроверить это дважды.)",
    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Не указан регион размещения этого сервера Nextcloud, что требуется для возможности проверки номеров телефонов без указания кода страны. Чтобы разрешить пользователям сервера указывать номера телефонов без указания кода страны, добавьте параметр «default_phone_region» с соответствующим кодом страны в соответствии с  {linkstart}ISO 3166-1↗{linkend}.",
    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ошибка запуска задачи планировщика с использованием интерфейса командной строки. Подробное сообщение об ошибке:",
    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Последняя фоновая задача была выполнена {relativeTime}. Похоже, что-то не в порядке.{linkstart}Проверьте настройки фонового задания ↗{linkend}. ",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Этот сервер не подключён к интернету: множество конечных устройств не могут быть доступны. Это означает, что не будут работать некоторые функции, такие как подключение внешнего хранилища, уведомления об обновлениях или установка сторонних приложений. Так же могут не работать удалённый доступ к файлам и отправка уведомлений по электронной почте. Для использования всех возможностей рекомендуется разрешить серверу доступ в Интернет.",
    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не настроена система кеширования. Для увеличения производительности сервера, по возможности, настройте memcache. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не найден подходящий источник случайных значений для PHP, что сильно влияет на уровень безопасности. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Используется PHP {version}. Рекомендуется обновить PHP, чтобы воспользоваться {linkstart}улучшениями производительности и безопасности, внедрёнными PHP Group ↗{linkend}, как только новая версия будет доступна в вашем дистрибутиве. ",
    "Nextcloud 23 is the last release supporting PHP 7.3. Nextcloud 24 requires at least PHP 7.4." : "Nextcloud 23 - это последний релиз, поддерживающий PHP 7.3. Для Nextcloud 24 необходимо иметь минимальную версию PHP 7.4.",
    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Заголовки обратного прокси настроены неправильно, либо подключение к серверу Nextcloud осуществляется через доверенный прокси. Если Nextcloud открыт не через доверенный прокси, то это проблема безопасности, которая может позволить атакующему подделать IP-адрес, определяемый сервером Nextcloud. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached настроен на распределенный кеш, но установлен не поддерживаемый модуль PHP \"memcache\". \\OC\\Memcache\\Memcached поддерживает только модуль \"memcached\", но не \"memcache\". См. {linkstart}вики-страницу memcached об обоих модулях ↗{linkend}.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Некоторые файлы не прошли проверку целостности. Дополнительная информация о том, как устранить данную проблему, представлена в {linkstart1}документации ↗{linkend}. ({linkstart2}Список проблемных файлов…{linkend} / {linkstart3}Сканировать ещё раз…{linkend})",
    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Модуль OPcache подсистемы PHP настроен некорректно. Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Недоступна функция PHP «set_time_limit». В случае остановки выполнения сценариев во время работы это может привести к повреждению установки сервера Nextcloud. Настоятельно рекомендуется включить эту функцию.",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Установленная версия PHP не поддерживает библиотеку FreeType, что приводит к неверному отображению изображений профиля и интерфейса настроек.",
    "Missing index \"{indexName}\" in table \"{tableName}\"." : "В таблице «{tableName}» отсутствует индекс «{indexName}».",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "В базе данных отсутствуют некоторые индексы. Так как создание таких индексов может занять достаточно продолжительное время, оно должно быть запущено вручную. Для создания индексов необходимо запустить команду «occ db:add-missing-indices» во время работы сервера Nextcloud. При созданных индексах, как правило, запросы к базе данных выполняются значительно быстрее.",
    "Missing primary key on table \"{tableName}\"." : "Отсутствует первичный ключ в таблице \"{tableName}\".",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "В базе данных отсутствуют некоторые первичные ключи. Поскольку добавление первичных ключей в большие таблицы могло занять некоторое время, они не добавлялись автоматически. Запустив команду «occ db: add-missing-primary-keys», эти недостающие первичные ключи можно добавить вручную, пока экземпляр продолжает работать.",
    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Отсутствует необязательный столбец \"{columnName}\" в таблице \"{tableName}\".",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "В базе данных отсутствуют некоторые необязательные столбцы. Из-за того, что добавление столбцов в больших таблицах может занять некоторое время, они не добавляются автоматически, если они могут быть необязательными. Запустив «occ db:add-missing-columns», эти недостающие столбцы можно добавить вручную, пока экземпляр продолжает работать. После добавления столбцов некоторые функции могут улучшить отзывчивость или удобство использования.",
    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "В системе не установлены рекомендуемые модули PHP. Для улучшения производительности и совместимости рекомендуется установить эти модули.",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "Модули «gmp» и / или «bcmath» подсистемы PHP не активированы. Эти модули необходимы при использовании аутентификации без пароля WebAuth.",
    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модуль php-imagick в этом случае не поддерживает SVG. Для лучшей совместимости рекомендуется установить его.",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Некоторые поля базы данных не были преобразованы в тип big int. Операция преобразования таких полей может занять продолжительное время и должа быть запущена вручную. Чтобы выполнить преобразование, необходимо включить режим обслуживания и запустить в терминале команду «occ db:convert-filecache-bigint». Дополнительная информация представлена в {linkstart}документации ↗{linkend}.",
    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "В настоящее время в качестве механизма БД используется SQLite. Для более крупных развёртываний рекомендуется перейти к использованию других баз данных.",
    "This is particularly recommended when using the desktop client for file synchronisation." : "Такой переход рекомендован и при использовании приложений-клиентов для синхронизации файлов.",
    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Для перехода на другую базу данных используйте команду: «occ db:convert-type» или обратитесь к {linkstart}документации ↗{linkend}.",
    "The PHP memory limit is below the recommended value of 512MB." : "Разрешённое максимальное значение использования памяти PHP ниже рекомендуемого значения в 512 МБ.",
    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Владельцем некоторых каталогов не является учётная запись, под которой исполняется процесс web-сервера. Как правило это случается при установке вручную. Проверьте права доступа к следующим каталогам приложения:",
    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL используется в качестве базы данных, но не поддерживает 4-байтовые символы.  Чтобы иметь возможность обрабатывать 4-байтовые символы (например, смайлики) без проблем в именах файлов или комментариях, рекомендуется включить 4-байтовую поддержку в MySQL.  Для получения более подробной информации обратитесь к {linkstart}документации ↗{linkend}.",
    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Этот экземпляр использует хранилище объектов на основе S3 в качестве основного хранилища. Загруженные файлы временно хранятся на сервере, поэтому рекомендуется иметь 50 ГБ свободного места во временном каталоге PHP. Проверьте журналы для получения полной информации о пути и доступном пространстве. Чтобы улучшить это, измените временный каталог в php.ini или выделите больше места по этому пути.",
    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Указанный в параметрах каталог для временных файлов не существует или недоступен для записи.",
    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Сервер создаёт небезопасные ссылки, несмотря на то, что к нему осуществлено безопасное подключение. Скорее всего, причиной являются неверно настроенные параметры обратного прокси и значения переменных перезаписи исходного адреса. Рекомендации по верной настройке приведены в {linkstart}документации ↗{linkend}.",
    "Error occurred while checking server setup" : "Произошла ошибка при проверке настроек сервера",
    "For more details see the {linkstart}documentation ↗{linkend}." : "За дополнительными сведениями обратитесь к {linkstart}документации ↗{linkend}.",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Каталог данных и файлы, возможно, доступны из интернета. Файл «.htaccess» не работает. Настоятельно рекомендуется настроить веб сервер таким образом, чтобы каталог данных не был доступен из внешней сети, либо переместить каталог данных за пределы корневого каталога веб-сервера.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не настроен на значение «{expected}». Это потенциальная проблема безопасности для устранения которой рекомендуется задать этот параметр.",
    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не настроен на значение «{expected}». Это может привести к неработоспособности некоторых из функций и рекомендуется изменить эти настройки.",
    "The \"{header}\" HTTP header doesn't contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Заголовок HTTP «{header}» не содержит параметр «{expected}». Это может привести к проблемам  безопасности. Рекомендуется задать этот параметр.",
    "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Заголовок HTTP «{header}» не содержит значения «{val1}», «{val2}», «{val3}» или «{val4}», что может привести к утечке информации об адресе источника перехода по ссылке. Для получения более подробной информации обратитесь к {linkstart}рекомендации W3C ↗{linkend}.",
    "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Заголовок HTTP «Strict-Transport-Security» должен быть настроен как минимум на «{seconds}» секунд. Для улучшения безопасности рекомендуется включить HSTS согласно нашим {linkstart}подсказкам по безопасности ↗{linkend}.",
    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}." : "Используется небезопасное соединение по протоколу HTTP.  Настоятельно рекомендуется настроить сервер на использование HTTPS согласно нашим {linkstart}подсказкам по безопасности ↗{linkend}.",
    "unknown text" : "неизвестный текст",
    "Hello world!" : "Привет мир!",
    "sunny" : "солнечно",
    "Hello {name}, the weather is {weather}" : "Здравствуйте, {name}! Погода сейчас  {weather}",
    "Hello {name}" : "Здравствуйте, {name}!",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Эти результаты поиска<script>alert(1)</script></strong>",
    "new" : "новый",
    "_download %n file_::_download %n files_" : ["скачать %n файл","скачать %n файла","скачать %n файлов","скачать %n файла"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Выполняется обновление. Не уходите с этой страницы, т.к. в некоторых случаях может прервать процесс.",
    "Update to {version}" : "Обновление до версии {version}",
    "An error occurred." : "Произошла ошибка.",
    "Please reload the page." : "Обновите страницу.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Обновление не удалось. Больше информации  о данной проблеме можно найти <a href=\"{url}\">в сообщении на нашем форуме</a>.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Обновление не удалось. Сообщите об этой проблеме <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">сообществу Nextcloud</a>.",
    "Continue to {productName}" : "Перейти к {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Обновление выполнено успешно. Перенаправление в {productName} через %n секунду.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунды.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд.","Обновление выполнено успешно. Перенаправление в {productName} через %n секунд."],
    "More apps" : "Ещё приложения",
    "Log in" : "Войти",
    "Logging in …" : "Вход в систему…",
    "Server side authentication failed!" : "Ошибка аутентификации на стороне сервера!",
    "Please contact your administrator." : "Обратитесь к своему администратору.",
    "An internal error occurred." : "Произошла внутренняя ошибка.",
    "Please try again or contact your administrator." : "Пожалуйста попробуйте ещё раз или свяжитесь с вашим администратором",
    "Password" : "Пароль",
    "Wrong username or password." : "Неверное имя пользователя или пароль.",
    "User disabled" : "Пользователь отключён",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "С вашего IP-адреса было выполнено множество неудачных попыток входа в систему. Следующую попытку можно будет выполнить через 30 секунд.",
    "Username or email" : "Имя пользователя или адрес эл. почты",
    "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
    "Browser not supported" : "Используемый браузер не поддерживается",
    "Passwordless authentication is not supported in your browser." : "Ваш браузер не поддерживает безпарольную аутентификацию",
    "Your connection is not secure" : "Соединение установлено с использованием небезопасного протокола",
    "Passwordless authentication is only available over a secure connection." : "Безпарольная аутентификация доступна только через защищённое соединение",
    "Reset password" : "Сбросить пароль",
    "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Письмо с инструкциями по сбросу пароля отправлено на адрес электронной почты этой учётной записи. Если это письмо не будет получено, проверьте папку «Спам» или сообщите об этом администратору системы.",
    "If it is not there ask your local administrator." : "Если письмо не будет получено, сообщите об этом администратору системы.",
    "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Свяжитесь со своим администратором.",
    "Password cannot be changed. Please contact your administrator." : "Пароль не может быть изменён. Свяжитесь со своим системным администратором.",
    "Back to login" : "Вернуться на страницу входа",
    "New password" : "Новый пароль",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши файлы хранятся в зашифрованном виде. После сброса пароля будет невозможно получить доступ к этим данным. Если вы не уверены что делать дальше — обратитесь к вашему системному администратору. Действительно продолжить?",
    "I know what I'm doing" : "Я понимаю, что делаю",
    "Resetting password" : "Сброс пароля",
    "Recommended apps" : "Рекомендованные приложения",
    "Loading apps …" : "Получение списка приложений...",
    "Could not fetch list of apps from the App Store." : "Не удалось получить список приложений.",
    "Installing apps …" : "Установка приложений...",
    "App download or installation failed" : "Не удалось скачать или установить приложение",
    "Cannot install this app because it is not compatible" : "Приложение не может быть установлено, так как оно несовместимо",
    "Cannot install this app" : "Это приложение не может быть установлено",
    "Skip" : "Пропустить",
    "Install recommended apps" : "Установить рекомендуемые приложения",
    "Schedule work & meetings, synced with all your devices." : "Составляйте графики работы и встреч, синхронизированные со всеми вашими устройствами.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Храните информацию о своих коллегах и друзьях в одном месте без утечки их личных данных.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Простое приложение электронной почты, прекрасно интегрированное с приложениями Files, Contacts и Calendar.",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Текстовые сообщения, видеозвонки, демонстрация содержимого экрана, онлайн общение и веб-конференции на ПК и мобильных устройствах. ",
    "Collaboratively edit office documents." : "Совместная работа над документами.",
    "Local document editing back-end used by the Collabora Online app." : "Исполняемый на стороне клиента компонент для редактирования документов, используемый приложением Collabora Online.",
    "Forgot password?" : "Забыли пароль?",
    "Log in with a device" : "Войти с устройства",
    "Back" : "Назад",
    "Login form is disabled." : "Форма входа отключена.",
    "Edit Profile" : "Редактирование профиля",
    "The headline and about sections will show up here" : "Разделы \"Заголовок\" и \"О вас\" будут отображаться здесь",
    "You have not added any info yet" : "Вы ещё не добавили никакой информации",
    "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
    "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
    "Reset search" : "Очистить поиск",
    "Start search" : "Запустить поиск",
    "Search for {name} only" : "Искать только для «{name}»",
    "No results for {query}" : "По запросу «{query}» ничего не найдено",
    "Press enter to start searching" : "Нажмите Enter для запуска поиска",
    "Start typing to search" : "Начините вводить символы для поиска",
    "Loading more results …" : "Загрузка дополнительных результатов…",
    "Load more results" : "Загрузить дополнительные результаты",
    "Search" : "Найти",
    "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Чтобы начать поиск необходимо ввести как минимум  {minSearchLength} символ","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символов","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа"],
    "Search {types} …" : "Поиск {types}…",
    "Settings" : "Параметры",
    "Could not load your contacts" : "Ошибка получения контактов",
    "Search contacts …" : "Поиск контакта…",
    "No contacts found" : "Контактов не найдено",
    "Show all contacts …" : "Показать все контакты…",
    "Install the Contacts app" : "Установить приложение Контакты",
    "Loading your contacts …" : "Загрузка контактов…",
    "Looking for {term} …" : "Поиск {term}…",
    "No" : "Нет",
    "Yes" : "Да",
    "No files in here" : "Здесь нет файлов",
    "New folder" : "Новая папка",
    "No more subfolders in here" : "Здесь нет вложенных папок",
    "Name" : "Имя",
    "Size" : "Размер",
    "Modified" : "Последнее изменение:",
    "\"{name}\" is an invalid file name." : "«{name}» — недопустимое имя файла.",
    "File name cannot be empty." : "Имя файла не может быть пустым.",
    "\"/\" is not allowed inside a file name." : "Символ «/» недопустим в имени файла.",
    "\"{name}\" is not an allowed filetype" : "«{name}» - недопустимый тип файла.",
    "{newName} already exists" : "«{newName}» уже существует",
    "Choose" : "Выбрать",
    "Copy" : "Копировать",
    "Move" : "Переместить",
    "Error loading file picker template: {error}" : "Ошибка при загрузке шаблона выбора файлов: {error}",
    "OK" : "ОК",
    "Error loading message template: {error}" : "Ошибка загрузки шаблона сообщений: {error}",
    "read-only" : "только для чтения",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} файлах в состоянии конфликта","{count} файла в состоянии конфликта","{count} файлов в состоянии конфликта","{count} файлов в состоянии конфликта"],
    "One file conflict" : "Один файл в состоянии конфликта",
    "New Files" : "Новые файлы",
    "Already existing files" : "Существующие файлы",
    "Which files do you want to keep?" : "Какие файлы вы хотите сохранить?",
    "If you select both versions, the copied file will have a number added to its name." : "При выборе обеих версий к названию копируемого файла будет добавлена цифра",
    "Cancel" : "Отмена",
    "Continue" : "Продолжить",
    "(all selected)" : "(все выбранные)",
    "({count} selected)" : "(выбрано: {count})",
    "Error loading file exists template" : "Ошибка при загрузке шаблона существующего файла",
    "Show list view" : "Просмотр списком",
    "Show grid view" : "Просмотр сеткой",
    "Pending" : "Ожидается",
    "Copy to {folder}" : "Скопировать в «{folder}»",
    "Move to {folder}" : "Переместить в «{folder}»",
    "Saving …" : "Сохранение…",
    "Authentication required" : "Требуется аутентификация ",
    "This action requires you to confirm your password" : "Это действие требует подтверждения паролем",
    "Confirm" : "Подтвердить",
    "Failed to authenticate, try again" : "Ошибка аутентификации. Попробуйте снова.",
    "seconds ago" : "только что",
    "Connection to server lost" : "Потеряно подключение к серверу",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Возникла проблема при загрузке страницы, повторная попытка через %n секунду","Возникла проблема при загрузке страницы, повторная попытка через %n секунды","Возникла проблема при загрузке страницы, повторная попытка через %n секунд","Возникла проблема при загрузке страницы, повторная попытка через %n секунд"],
    "Add to a project" : "Добавить к проекту",
    "Show details" : "Подробные сведения",
    "Hide details" : "Скрыть подробные сведения",
    "Rename project" : "Переименовать проект",
    "Failed to rename the project" : "Не удалось переименовать проект",
    "Failed to create a project" : "Не удалось создать проект",
    "Failed to add the item to the project" : "Не удалось добавить элемент к проекту",
    "Connect items to a project to make them easier to find" : "Подключите элементы к проекту, чтобы их было легче найти",
    "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
    "New in" : "Новые возможности",
    "View changelog" : "Просмотреть изменения",
    "Very weak password" : "Очень слабый пароль",
    "Weak password" : "Слабый пароль",
    "So-so password" : "Так себе пароль",
    "Good password" : "Хороший пароль",
    "Strong password" : "Надёжный пароль",
    "No action available" : "Нет доступных действий",
    "Error fetching contact actions" : "Ошибка получения действий контакта",
    "Non-existing tag #{tag}" : "Несуществующая метка #{tag}",
    "restricted" : "ограниченный",
    "invisible" : "невидимый",
    "Delete" : "Удалить",
    "Rename" : "Переименовать",
    "Collaborative tags" : "Совместные теги",
    "No tags found" : "Метки не найдены",
    "Personal" : "Личное",
    "Users" : "Пользователи",
    "Apps" : "Приложения",
    "Admin" : "Администрирование",
    "Help" : "Помощь",
    "Access forbidden" : "Доступ запрещён",
    "Profile not found" : "Профиль не найден",
    "The profile does not exist." : "Профиль не существует",
    "Back to %s" : "Вернуться к %s",
    "File not found" : "Файл не найден",
    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документ не найден на сервере. Возможно доступ к нему был удален или истек срок действия доступа.",
    "Too many requests" : "Превышено количество запросов",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Превышено количество запросов из вашей сети. Попробуйте позднее или сообщите администратору об этой ошибке.",
    "Error" : "Ошибка",
    "Previous" : "Предыдущий",
    "Internal Server Error" : "Внутренняя ошибка сервера",
    "The server was unable to complete your request." : "Запрос не может быть обработан сервером.",
    "If this happens again, please send the technical details below to the server administrator." : "Если это случится ещё раз, отправьте администратору сервера подробное сообщение о произошедшем, приведённое ниже.",
    "More details can be found in the server log." : "Подробную информацию можно найти в журнале сервера.",
    "Technical details" : "Технические подробности",
    "Remote Address: %s" : "Удаленный адрес: %s",
    "Request ID: %s" : "ID Запроса: %s",
    "Type: %s" : "Тип: %s",
    "Code: %s" : "Код: %s",
    "Message: %s" : "Сообщение: %s",
    "File: %s" : "Файл: «%s»",
    "Line: %s" : "Строка: %s",
    "Trace" : "Трассировка",
    "Security warning" : "Предупреждение безопасности",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
    "Create an <strong>admin account</strong>" : "Создать <strong>учётную запись администратора</strong>",
    "Username" : "Имя пользователя",
    "Show password" : "Показать пароль",
    "Toggle password visibility" : "Переключить видимость пароля",
    "Storage & database" : "Хранилище и база данных",
    "Data folder" : "Каталог с данными",
    "Configure the database" : "Настройка базы данных",
    "Only %s is available." : "Доступен только %s.",
    "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
    "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
    "Database user" : "Пользователь базы данных",
    "Database password" : "Пароль базы данных",
    "Database name" : "Название базы данных",
    "Database tablespace" : "Табличное пространство базы данных",
    "Database host" : "Хост базы данных",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
    "Performance warning" : "Предупреждение о производительности",
    "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
    "Install" : "Установить",
    "Installing …" : "Установка ...",
    "Need help?" : "Требуется помощь?",
    "See the documentation" : "Посмотреть документацию",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Похоже, вы пытаетесь переустановить Nextcloud. Однако файл «CAN_INSTALL» отсутствует в вашем каталоге конфигурации. Чтобы продолжить создайте файл «CAN_INSTALL» в каталоге конфигурации.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не удалось удалить «CAN_INSTALL» из каталога конфигурации. Удалите этот файл вручную.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript.  {linkstart}Включите JavaScript{linkend} и обновите страницу.",
    "Skip to main content" : "Перейти к основному содержанию",
    "Skip to navigation of app" : "Перейти к навигации по приложению",
    "Get your own free account" : "Создайте свою бесплатную учётную запись",
    "%s's homepage" : "Домашняя страница %s",
    "Contacts" : "Контакты",
    "Contacts menu" : "Меню контактов",
    "Confirm your password" : "Подтвердите свой пароль",
    "Connect to your account" : "Вход в систему",
    "Please log in before granting %1$s access to your %2$s account." : "Для предоставления %1$s доступа к учётной записи %2$s необходимо войти в систему.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Если вы не пытались настроить новое устройство или приложение, значит, кто-то пытается получить доступ к вашим данным. В этом случае свяжитесь с администратором системы.",
    "App token" : "Токен приложения",
    "Grant access" : "Разрешить доступ",
    "Alternative log in using app token" : "Войти по токену приложения",
    "Account access" : "Доступ к аккаунту",
    "Currently logged in as %1$s (%2$s)." : "Вход в систему выполнен под именем %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Вы собираетесь разрешить приложению %1$s доступ к своей учётной записи %2$s.",
    "Account connected" : "Аккаунт подключен",
    "Your client should now be connected!" : "Приложение-клиент подключено.",
    "You can close this window." : "Можете закрыть это окно.",
    "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
    "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
    "Please type in your email address to request a temporary password" : "Введите свой адрес эл. почты для запроса временного пароля",
    "Email address" : "Адрес эл. почты",
    "Password sent!" : "Пароль отправлен",
    "You are not authorized to request a password for this share" : "У вас недостаточно прав для запроса пароля для доступа к этому общему ресурсу",
    "Go to %s" : "Перейти к %s",
    "Two-factor authentication" : "Двухфакторная аутентификация",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Повышенная безопасность включена для вашей учетной записи. Выберете второй фактор для подтверждения подлинности пользователя.",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Не удалось использовать хотя бы один из двух настроенных способов двуфакторной аутентификации. Обратитесь к администратору.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Двухфакторная аутентификация включена но не сконфигурирована для вашей учетной записи. Обратитесь к администратору сервера для консультации. ",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Двухфакторная аутентификация включена но не сконфигурирована для вашей учетной записи. Пожалуйста, продолжите, чтобы установить двухфакторную аутентификацию.",
    "Set up two-factor authentication" : "Установить двухфакторную аутентификацию",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Двухфакторное подтверждение подлинности включено в настройках но ваша учётная запись еще не сконфигурирована для его использования. Используйте один из резервных кодов для входа в аккаунт или свяжитесь с вашим администратором для получения помощи.",
    "Use backup code" : "Использовать резервный код",
    "Cancel login" : "Отменить вход",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Повышенная безопасность включена для вашей учетной записи. Выберите провайдера для настройки:",
    "Error while validating your second factor" : "Ошибка проверки кода",
    "Access through untrusted domain" : "Доступ через недоверенный домен",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Обратитесь к администратору. Если вы являетесь администратором этого сервера, отредактируйте параметр «trusted_domains» в файле «config/config.php». Пример настройки можно найти в файле «config/config.sample.php».",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Дополнительная информация как это настроить может быть найдена в %1$sдокументации %2$s",
    "App update required" : "Требуется обновление приложения",
    "%1$s will be updated to version %2$s" : "%1$s будет обновлено до версии %2$s",
    "The following apps will be updated:" : "Следующие приложения будут обновлены:",
    "These incompatible apps will be disabled:" : "Эти несовместимые приложения будут отключены:",
    "The theme %s has been disabled." : "Тема %s была отключена.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Перед продолжением убедитесь, что вы сделали резервную копию базы данных, каталога конфигурации и каталога с данными.",
    "Start update" : "Запустить обновление",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Чтобы избежать тайм-аутов в крупных установках, вместо этого можно выполнить следующую команду в каталоге установки:",
    "Detailed logs" : "Подробные журналы",
    "Update needed" : "Требуется обновление",
    "Please use the command line updater because you have a big instance with more than 50 users." : "В этом развёртывании создано более 50 пользователей. Используйте инструмент командной строки для выполнения обновления.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Для получения помощи обратитесь к <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документации</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Я знаю, что в случае продолжения обновления через веб-интерфейс возникает риск тайм-аута запроса, который может привести к потере данных. У меня есть резервная копия, и я знаю, как восстановить систему в случае сбоя.",
    "Upgrade via web on my own risk" : "Обновить используя веб-интерфейс на мой страх и риск",
    "Maintenance mode" : "Режим обслуживания",
    "This %s instance is currently in maintenance mode, which may take a while." : "Этот сервер %s находится в режиме технического обслуживания, которое может занять некоторое время.",
    "This page will refresh itself when the instance is available again." : "Эта страница обновится автоматически когда сервер снова станет доступен.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Обратитесь к вашему системному администратору если это сообщение не исчезает или появляется неожиданно.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Проверка таблицы %s",
    "This server has no working Internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the Internet to enjoy all features." : "Этот сервер не подключён к интернету: множество конечных устройств не могут быть доступны. Это означает, что не будут работать некоторые функции, такие как подключение внешнего хранилища, уведомления об обновлениях или установка сторонних приложений. Так же могут не работать удалённый доступ к файлам и отправка уведомлений по электронной почте. Для использования всех возможностей рекомендуется разрешить серверу доступ в Интернет.",
    "Nextcloud 20 is the last release supporting PHP 7.2. Nextcloud 21 requires at least PHP 7.3." : "Nextcloud версии 20 — последний выпуск, поддерживающий PHP версии 7.2. Для работы Nextcloud версии 21 потребуется PHP версии не ниже 7.3.",
    "The PHP OPcache module is not loaded. {linkstart}For better performance it is recommended ↗{linkend} to load it into your PHP installation." : "Не загружен PHP-модуль OPcache. Рекомендуется настроить этот модуль для {linkstart}улучшения производительности ↗{linkend}.",
    "The PHP OPcache module is not properly configured. {linkstart}For better performance it is recommended ↗{linkend} to use the following settings in the <code>php.ini</code>:" : "Система кеширования PHP OPcache не настроена верно. {linkstart}Для обеспечения лучшей производительности рекомендуется ↗{linkend} задать в файле <code>php.ini</code> следующие параметры:",
    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running 'occ db:convert-filecache-bigint' those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Некоторые индексы базы данных не были преобразованы в тип big int. Так как преобразование таких индексов может занять продолжительное время, оно должно быть запущенно вручную. Чтобы выполнить преобразование, необходимо включить режим обслуживания и запустить в терминале команду «occ db:convert-filecache-bigint». Дополнительные сведения приведены {linkstart}на соответствующей странице документации ↗{linkend}.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the {linkstart}documentation ↗{linkend}." : "Для миграции на другую базу данных используйте команду 'occ db:convert-type' или обратитесь к {linkstart}документации ↗{linkend}.",
    "Your data directory and files are probably accessible from the Internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Каталог данных и файлы, возможно, доступны из интернета. Файл «.htaccess» не работает. Настоятельно рекомендуется настроить веб сервер таким образом, чтобы каталог данных не был доступен из внешней сети, либо переместить каталог данных за пределы корневого каталога веб-сервера.",
    "More" : "Дополнительно",
    "More apps menu" : "Меню дополнительных приложений",
    "Settings menu" : "Меню настроек",
    "The password is wrong. Try again." : "Неверный пароль. Повторите попытку.",
    "Setup two-factor authentication" : "Установка двухфакторной аутентификации",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Эта сборка Nextcloud для сообщества не обслуживается, мгновенные уведомления недоступны.",
    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications have been disabled to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at nextcloud.com/enterprise." : "Это неподдерживаемая сборка сообщества Nextcloud. Размер этого развёртывания не позволяет,  гарантировать производительность, надежность и масштабируемость. Push-уведомления отключены, чтобы не перегружать бесплатный сервис разработчиков Nextcloud. Узнайте больше о преимуществах корпоративной версии Nextcloud на сайте nextcloud.com/enterprise.",
    "You haven't added any info yet" : "Вы еще не добавили никакой информации",
    "{user} hasn't added any info yet" : "{user} ещё не добавил никакой информации"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
